@@ -23,14 +23,14 @@ SnippetAttachmentWidget::SnippetAttachmentWidget(QWidget *parent)
     layout->setContentsMargins({});
 
     mLineEdit->setObjectName(QLatin1StringView("lineedit"));
-    mLineEdit->setPlaceholderText(i18n("Click on button for selecting attachment file"));
+    mLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Click on button for selecting attachment file"));
     layout->addWidget(mLineEdit);
     mLineEdit->setReadOnly(true);
 
     auto button = new QToolButton(this);
     button->setObjectName(QLatin1StringView("button"));
-    button->setToolTip(i18n("Select Attachments"));
-    button->setText(i18n("..."));
+    button->setToolTip(i18nc("@info:tooltip", "Select Attachments"));
+    button->setText(i18n("…"));
     layout->addWidget(button);
     connect(button, &QToolButton::clicked, this, &SnippetAttachmentWidget::slotSelectAttachment);
 }
